Name:          calibre
Version:       3.27.1
Release:       %mkrel 2
Summary:       E-book converter and library management
Group:         Office/Utilities
License:       GPLv3
URL:           http://calibre-ebook.com/
Source0:       https://download.calibre-ebook.com/%{version}/%{name}-%{version}.tar.xz
Source2:       %{name}-mount-helper
# compilation issue with missing includes
Source3:       compile-3.27.1.patch
# don't check for new upstream version (that's what packagers do)
# otherwise the plugins are safe to be updated in ~/.config/calibre/plugins/
Patch1:        calibre-2.9.0-fdo-no_update.patch
# Hide individual launchers for ebook-edit, ebook-viewer and lrfviewer as they
# are all accessible in the main calibre GUI.(from Fedora)
Patch6:        calibre-2.6.0-fdo-nodisplay.patch

BuildRequires:    bash-completion
BuildRequires:    chmlib-devel
BuildRequires:    desktop-file-utils
BuildRequires:    icu-devel
BuildRequires:    imagemagick-devel >= 6.5.9
BuildRequires:    libwmf-devel
BuildRequires:    pkgconfig(libmtp)
BuildRequires:    pkgconfig(libpodofo-0)
BuildRequires:    pkgconfig(poppler-glib)
BuildRequires:    pkgconfig(poppler-qt5) >= 0.12
BuildRequires:    pkgconfig(python) >= 2.7
BuildRequires:    pkgconfig(Qt5Core)
BuildRequires:    pkgconfig(Qt5Gui)
BuildRequires:    pkgconfig(sqlite3)
BuildRequires:    python-apsw
BuildRequires:    python-beautifulsoup
BuildRequires:    python-cssselect
BuildRequires:    python-cssutils >= 0.9.9
BuildRequires:    python-dateutil
BuildRequires:    python-html5-parser
BuildRequires:    python-imaging
BuildRequires:    python-lxml
BuildRequires:    python-mechanize
BuildRequires:    python-msgpack
BuildRequires:    python-qt5-devel
BuildRequires:    python-qt5-webkit
BuildRequires:    python-regex
BuildRequires:    python-setuptools
BuildRequires:    python-sip
BuildRequires:    python-six
BuildRequires:    qt5-devel
BuildRequires:    qt5eventdispatchersupport-devel
BuildRequires:    qt5fontdatabasesupport-devel
BuildRequires:    qt5platformsupport-devel
BuildRequires:    qt5platformsupport-private-devel
BuildRequires:    qt5servicesupport-devel
BuildRequires:    qt5themesupport-devel
BuildRequires:    unzip
BuildRequires:    xdg-utils
#
# If python-feedparser is installed at build time there's problems with links.
# See https://bugzilla.redhat.com/show_bug.cgi?id=1026469
BuildConflicts: python-feedparser
Requires:    python-dbus
Requires:    python-qt5-core
Requires:    python-qt5-svg
Requires:    python-qt5-webkit
Requires:    python-qt5-webkitwidgets
Requires:    python-qt5-widgets
Requires:    python-qt5-gui
Requires:    python-qt5-printsupport
Requires:    python-qt5-network
Requires:    python-pypdf
Requires:    python-cherrypy
Requires:    python-cssutils
Requires:    python-cssselect
Requires:    ImageMagick
Requires:    python-odf
Requires:    python-lxml
Requires:    python-imaging
Requires:    python-mechanize
Requires:    python-msgpack
Requires:    python-dateutil
Requires:    python-genshi
Requires:    python-beautifulsoup
Requires:    python-netifaces
Requires:    poppler
Requires:    python-html5-parser
# Require the packages of the files which are symlinked by calibre
Requires:    fonts-ttf-liberation
# E-mail functionality requires this package
# see https://bugs.launchpad.net/calibre/+bug/739073
Requires:    python-dnspython
# Spotted by mga#11368
Requires:    python-apsw
Requires:    python-regex

%description
Calibre is meant to be a complete e-library solution. It includes library
management, format conversion, news feeds to ebook conversion as well as
e-book reader sync features.

Calibre is primarily a ebook cataloging program. It manages your ebook
collection for you. It is designed around the concept of the logical book,
i.e. a single entry in the database that may correspond to ebooks in several
formats. It also supports conversion to and from a dozen different ebook
formats.

Supported input formats are: MOBI, LIT, PRC, EPUB, CHM, ODT, HTML, CBR, CBZ,
RTF, TXT, PDF and LRS.

%prep
%autosetup -p1

# remove redundant / non-free fonts
rm -rf resources/fonts/*/

# dos2unix newline conversion
sed -i -e 's/\r//' src/calibre/web/feeds/recipes/*

# fix the location of liberation default font
sed -i -e "s:P('fonts/liberation/Liberation:('%{_datadir}/fonts/TTF/liberation/Liberation:" \
  src/calibre/utils/magick/draw.py
sed -i -e "s:P('fonts/liberation/Liberation:('%{_datadir}/fonts/TTF/liberation/Liberation:" \
  src/calibre/library/catalogs/epub_mobi_builder.py
sed -i -e "s:P('fonts/liberation/Liberation:('%{_datadir}/fonts/TTF/liberation/Liberation:" \
  src/calibre/ebooks/oeb/polish/tests/base.py
sed -i -e "s:P('fonts/liberation/Liberation:('%{_datadir}/fonts/TTF/liberation/Liberation:" \
  src/calibre/ebooks/__init__.py
sed -i -e "s:P('fonts/liberation/Liberation:('%{_datadir}/fonts/TTF/liberation/Liberation:" \
  src/calibre/web/feeds/news.py
sed -i -e "s:P('fonts/liberation/Liberation:('%{_datadir}/fonts/TTF/liberation/Liberation:" \
  recipes/*_ke.recipe

# remove shebangs
sed -i -e '/^#!\//, 1d' src/calibre/*/*/*/*.py
sed -i -e '/^#!\//, 1d' src/calibre/*/*/*.py
sed -i -e '/^#![ ]*\//, 1d' src/calibre/*/*.py
sed -i -e '/^#!\//, 1d' src/calibre/*.py
sed -i -e '/^#!\//, 1d' src/templite/*.py
sed -i -e '/^#!\//, 1d' resources/default_tweaks.py
sed -i -e '/^#!\//, 1d' recipes/*.recipe

# libdir
sed -i -e 's,/usr/lib,%{_libdir},g' setup/build_environment.py

chmod -x src/calibre/*/*/*/*.py
chmod -x src/calibre/*/*/*.py
chmod -x src/calibre/*/*.py
chmod -x src/calibre/*.py
chmod -x recipes/*.recipe

%build
OVERRIDE_CFLAGS="%{optflags}" python setup.py build

%install
mkdir -p %{buildroot}%{_datadir}

# create directories for xdg-utils
mkdir -p %{buildroot}%{_datadir}/icons
mkdir -p %{buildroot}%{_datadir}/icons/hicolor
mkdir -p %{buildroot}%{_datadir}/packages
mkdir -p %{buildroot}%{_datadir}/mime
mkdir -p %{buildroot}%{_datadir}/mime/packages
mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/desktop-directories

# create directory for calibre environment module
# the install script assumes it's there.
mkdir -p %{buildroot}%{python2_sitelib}

# create directory for completion files, so calibre knows where
# to install them
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions

XDG_DATA_DIRS="%{buildroot}%{_datadir}" \
XDG_UTILS_INSTALL_MODE="system" \
LIBPATH="%{_libdir}" \
python setup.py install --root=%{buildroot}%{_prefix} \
            --prefix=%{_prefix} \
            --libdir=%{_libdir} \
            --staging-libdir=%{buildroot}%{_libdir} \
# remove shebang from init_calibre.py here because
# it just got spawned by the install script
sed -i -e '/^#!\//, 1d' %{buildroot}%{python_sitelib}/init_calibre.py

# icons
mkdir -p %{buildroot}%{_datadir}/pixmaps/
cp -p resources/images/library.png        \
    %{buildroot}%{_datadir}/pixmaps/%{name}-gui.png
cp -p resources/images/viewer.png        \
    %{buildroot}%{_datadir}/pixmaps/calibre-viewer.png
cp -p resources/images/tweak.png        \
    %{buildroot}%{_datadir}/pixmaps/calibre-ebook-edit.png

# every file is empty here
find %{buildroot}%{_datadir}/mime -maxdepth 1 -type f|xargs rm -f

# the portable batch (>=0.8.5) is not needed
rm -f %{buildroot}%{_bindir}/calibre-portable.bat

# packages aren't allowed to register mimetypes like this
rm -f %{buildroot}%{_datadir}/applications/defaults.list
rm -f %{buildroot}%{_datadir}/applications/mimeinfo.cache
rm -f %{buildroot}%{_datadir}/mime/application/*.xml
rm -f %{buildroot}%{_datadir}/mime/text/*.xml

desktop-file-validate \
    %{buildroot}%{_datadir}/applications/calibre-ebook-edit.desktop
desktop-file-validate \
    %{buildroot}%{_datadir}/applications/calibre-ebook-viewer.desktop
desktop-file-validate \
    %{buildroot}%{_datadir}/applications/calibre-gui.desktop
desktop-file-validate \
    %{buildroot}%{_datadir}/applications/calibre-lrfviewer.desktop

# mimetype icon for lrf
rm -rf %{buildroot}%{_datadir}/icons/hicolor/128x128
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/mimetypes
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
cp -p resources/images/mimetypes/lrf.png \
      %{buildroot}%{_datadir}/icons/hicolor/scalable/mimetypes/application-x-sony-bbeb.png
cp -p resources/images/viewer.png \
      %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/calibre-viewer.png

# these are provided as separate packages
rm -rf %{buildroot}%{_libdir}/%{name}/{odf,cherrypy,pyPdf,encutils,cssutils}
rm -rf %{buildroot}%{_libdir}/%{name}/cal/utils/genshi
rm -rf %{buildroot}%{_libdir}/%{name}/cal/trac

# link to system fonts after we have deleted the non-free ones
# http://oldbugs.calibre-ebook.com/ticket/3832
mkdir -p %{buildroot}%{_datadir}/%{name}/fonts/prs500
ln -s %{_datadir}/fonts/TTF/liberation/LiberationSans-Regular.ttf \
      %{buildroot}%{_datadir}/%{name}/fonts/prs500/tt0003m_.ttf
ln -s %{_datadir}/fonts/TTF/liberation/LiberationSerif-Regular.ttf \
      %{buildroot}%{_datadir}/%{name}/fonts/prs500/tt0011m_.ttf
ln -s %{_datadir}/fonts/TTF/liberation/LiberationMono-Regular.ttf \
      %{buildroot}%{_datadir}/%{name}/fonts/prs500/tt0419m_.ttf

# rm empty feedparser files.
rm -rf %{buildroot}%{_libdir}/%{name}/%{name}/web/feeds/feedparser.*

ln -s %{python_sitelib}/feedparser.py \
      %{buildroot}%{_libdir}/%{name}/%{name}/web/feeds/feedparser.py
ln -s %{python_sitelib}/feedparser.pyc \
      %{buildroot}%{_libdir}/%{name}/%{name}/web/feeds/feedparser.pyc
ln -s %{python_sitelib}/feedparser.pyo \
      %{buildroot}%{_libdir}/%{name}/%{name}/web/feeds/feedparser.pyo

# localization has changed since calibre-0.8.5
# locale.zip is treated internally at runtime
# so the traditional locale fixes are moot.
# locales should still be looked for in the proper place
# but under the new localization zip-based schema
sed -i -e 's:localization/locale.zip:%{_datadir}/%{name}/localization/locales.zip:' %{buildroot}%{_libdir}/%{name}/%{name}/utils/localization.py

rm -f %{buildroot}%{_bindir}/%{name}-uninstall

cp -a %{SOURCE2} %{buildroot}%{_bindir}/


%files
%doc COPYRIGHT LICENSE Changelog.yaml
%{_bindir}/calibre
%{_bindir}/calibre-complete
%{_bindir}/calibre-customize
%{_bindir}/calibre-debug
%{_bindir}/calibre-parallel
%{_bindir}/calibre-server
%{_bindir}/calibre-smtp
%{_bindir}/calibre-mount-helper
%{_bindir}/calibredb
%{_bindir}/ebook-convert
%{_bindir}/ebook-device
%{_bindir}/ebook-meta
%{_bindir}/ebook-viewer
%{_bindir}/ebook-polish
%{_bindir}/ebook-edit
%{_bindir}/fetch-ebook-metadata
%{_bindir}/lrf2lrs
%{_bindir}/lrfviewer
%{_bindir}/lrs2lrf
%{_bindir}/markdown-calibre
%{_bindir}/web2disk
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/zsh/site-functions/_%{name}
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/pixmaps/*
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/mimetypes/*
%{_datadir}/metainfo/%{name}-*.appdata.xml
%{python2_sitelib}/init_calibre.py*


%changelog
* Wed Oct 17 2018 bcornec <bcornec> 3.27.1-2.mga6
+ Revision: 1321238
- Adds a missing Requires python-msgpack dep
- Update to upstream calibre 3.27.1 to fix mga#22814

* Sun Jul 02 2017 akien <akien> 2.85.1-2.mga6
+ Revision: 1108956
- Rebuild for podofo 0.9.6~svn

* Wed May 17 2017 tarakbumba <tarakbumba> 2.85.1-1.mga6
+ Revision: 1102572
- Update to 2.85.1 version

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 2.81.0-2.mga6
+ Revision: 1092685
- Rebuild for icu-58.2

* Mon Mar 13 2017 tarakbumba <tarakbumba> 2.81.0-1.mga6
+ Revision: 1092487
- Update to 2.81.0 version

* Wed Mar 01 2017 tarakbumba <tarakbumba> 2.80.0-1.mga6
+ Revision: 1088217
- Update to 2.80.0 version
- Update to 2.78.0 version

* Wed Jan 04 2017 tarakbumba <tarakbumba> 2.76.0-1.mga6
+ Revision: 1080115
- Update to 2.76.0 version
- Update to 2.75.1 version (fixes mga#20028)

* Sat Aug 13 2016 luigiwalser <luigiwalser> 2.58.0-2.mga6
+ Revision: 1046169
- test rebuild for poppler

* Sat Jun 04 2016 tarakbumba <tarakbumba> 2.58.0-1.mga6
+ Revision: 1020218
- Update to 2.58.0 version

* Sun May 22 2016 tarakbumba <tarakbumba> 2.57.1-1.mga6
+ Revision: 1017828
- Update to 2.57.1 version

* Fri May 13 2016 shlomif <shlomif> 2.56.0-2.mga6
+ Revision: 1014870
- Rebuild for new icu

* Tue May 10 2016 tarakbumba <tarakbumba> 2.56.0-1.mga6
+ Revision: 1012237
- Update to 2.56.0 version

* Sat Apr 16 2016 tarakbumba <tarakbumba> 2.55.0-1.mga6
+ Revision: 1002853
- Update to 2.55.0 version

* Sat Apr 02 2016 tarakbumba <tarakbumba> 2.54.0-1.mga6
+ Revision: 997698
- Update to 2.54.0 version

* Sun Mar 13 2016 tarakbumba <tarakbumba> 2.53.0-1.mga6
+ Revision: 990089
- Update to 2.53.0 version

* Tue Mar 01 2016 tarakbumba <tarakbumba> 2.52.0-1.mga6
+ Revision: 981158
- Update to 2.52.0 version

* Mon Feb 15 2016 tarakbumba <tarakbumba> 2.51.0-1.mga6
+ Revision: 961655
- Update to 2.51.0 version

* Sun Feb 07 2016 tarakbumba <tarakbumba> 2.50.1-1.mga6
+ Revision: 942206
- Update to 2.50.1 version

* Fri Jan 22 2016 tarakbumba <tarakbumba> 2.49.0-2.mga6
+ Revision: 926598
- Add missing req python-feedparser
- Adjust specfile a bit to fit new python policy

* Sun Jan 17 2016 tarakbumba <tarakbumba> 2.49.0-1.mga6
+ Revision: 924800
- Update to 2.49.0 version

* Sat Jan 02 2016 tarakbumba <tarakbumba> 2.48.0-1.mga6
+ Revision: 918090
- Update to 2.48.0 version

* Fri Jan 01 2016 luigiwalser <luigiwalser> 2.47.0-2.mga6
+ Revision: 917819
- rebuild for icu

* Mon Dec 28 2015 tarakbumba <tarakbumba> 2.47.0-1.mga6
+ Revision: 916640
- Update to 2.47.0 version

* Sat Dec 12 2015 tarakbumba <tarakbumba> 2.46.0-1.mga6
+ Revision: 909604
- Update to 2.46.0 version

* Thu Dec 03 2015 tarakbumba <tarakbumba> 2.45.0-1.mga6
+ Revision: 907927
- Update to 2.45.0 version

* Sat Nov 21 2015 tarakbumba <tarakbumba> 2.44.1-1.mga6
+ Revision: 904744
- Update to 2.44.1 version

* Sat Nov 14 2015 tarakbumba <tarakbumba> 2.44.0-1.mga6
+ Revision: 903121
- Update to 2.44.0 version

* Sun Nov 08 2015 tarakbumba <tarakbumba> 2.43.0-1.mga6
+ Revision: 898537
- Update to 2.43.0 version

* Tue Nov 03 2015 tarakbumba <tarakbumba> 2.42.0-1.mga6
+ Revision: 897486
- Updated to 2.42.0 version

* Sat Oct 17 2015 tarakbumba <tarakbumba> 2.41.0-1.mga6
+ Revision: 892261
- Update to 2.41.0 version

* Sun Oct 04 2015 tarakbumba <tarakbumba> 2.40.0-1.mga6
+ Revision: 886054
- Update to 2.40.0 version

* Fri Oct 02 2015 tarakbumba <tarakbumba> 2.39.0-1.mga6
+ Revision: 885620
- Update to 2.39.0 version

* Sat Jul 25 2015 tv <tv> 2.31.0-4.mga6
+ Revision: 857395
- rebuild for new libicu

* Sat Jul 25 2015 tv <tv> 2.31.0-3.mga6
+ Revision: 857390
- rebuild for new libicu
+ cjw <cjw>
- rebuild for icu 55

* Tue Jun 23 2015 tarakbumba <tarakbumba> 2.31.0-1.mga6
+ Revision: 841413
- Update to 2.31.0 version

* Mon Feb 23 2015 tarakbumba <tarakbumba> 2.20.0-1.mga5
+ Revision: 816767
- Update to 2.20.0 version
- Drop calibre-2.12.0-mga-use_uppercase_in_regex_core.patch in order to fix mga#15342
- Add uppercase_digit_in_regex_core.patch in order to fix ebook-edit utility

* Wed Jan 07 2015 ovitters <ovitters> 2.13.0-2.mga5
+ Revision: 809159
- requires python-dbus (mga#14978)

* Sat Dec 20 2014 tarakbumba <tarakbumba> 2.13.0-1.mga5
+ Revision: 804342
- Update to version 2.13.0
- Cleanup requires; do not require python-qt5 meta package
- Use autosetup macro
- Use uppercase for CHARSET_ESCAPES values in regex_core.py to prevent ebook-edit crash
- Re-enable calibre-2.9.0-mga-no_build_threads.patch
- Update to 2.12.0 version

* Sat Nov 15 2014 tarakbumba <tarakbumba> 2.10.0-1.mga5
+ Revision: 797302
- Update to 2.10.0 version
- Fix calibre-2.9.0-mga-no_build_threads.patch
- Update to 2.9.0 version
- Workaround multithread build on BS
- Update to 2.8.0 version

* Wed Oct 15 2014 umeabot <umeabot> 1.48.0-5.mga5
+ Revision: 751069
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.48.0-4.mga5
+ Revision: 693560
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.48.0-3.mga5
+ Revision: 678297
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 tv <tv> 1.48.0-2.mga5
+ Revision: 673053
- rebuild for new lib64podofo

* Sat Aug 16 2014 dams <dams> 1.48.0-1.mga5
+ Revision: 664418
- new version 1.48.0

* Wed Jul 23 2014 dams <dams> 1.45.0-1.mga5
+ Revision: 655805
- new version 1.45.0

* Sat Jun 28 2014 pterjan <pterjan> 1.42.0-1.mga5
+ Revision: 640912
- 1.42.0
- Rebuild for new Python

* Sat May 17 2014 dams <dams> 1.37.0-1.mga5
+ Revision: 623466
- new version 1.37.0

* Mon Apr 28 2014 dams <dams> 1.34.0-1.mga5
+ Revision: 618671
- new version 1.34.0

* Sat Apr 05 2014 wally <wally> 1.31.0-2.mga5
+ Revision: 611997
- rebuild for new icu

* Fri Apr 04 2014 dams <dams> 1.31.0-1.mga5
+ Revision: 611621
- new version 1.31.0

* Fri Mar 28 2014 dams <dams> 1.30.0-1.mga5
+ Revision: 609101
- new version 1.30.0

* Fri Mar 21 2014 dams <dams> 1.29.0-1.mga5
+ Revision: 606406
- new version 1.29.0

* Fri Mar 14 2014 dams <dams> 1.28.0-1.mga5
+ Revision: 603683
- new version 1.28.0

* Mon Mar 10 2014 dams <dams> 1.27.0-1.mga5
+ Revision: 601739
- new version 1.27.0

* Mon Feb 24 2014 dams <dams> 1.25.0-1.mga5
+ Revision: 596212
- new version 1.25.0

* Fri Feb 14 2014 dams <dams> 1.24.0-1.mga5
+ Revision: 591435
- new version 1.24.0

* Fri Feb 07 2014 dams <dams> 1.23.0-1.mga5
+ Revision: 585400
- new version 1.23

* Wed Feb 05 2014 dams <dams> 1.22.0-1.mga5
+ Revision: 582795
- update BR (python-cssselect)
- new version 1.22.0

* Thu Jan 09 2014 malo <malo> 1.11.0-2.mga4
+ Revision: 565780
- remove requires to python-django-tagging (mga#12191)

* Wed Nov 20 2013 dams <dams> 1.11.0-1.mga4
+ Revision: 552010
- new version 1.11.0

* Mon Oct 21 2013 umeabot <umeabot> 1.6.0-2.mga4
+ Revision: 541101
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 dams <dams> 1.6.0-1.mga4
+ Revision: 495110
- new version 1.6.0

* Fri Oct 04 2013 dams <dams> 1.5.0-2.mga4
+ Revision: 491326
- add 'python-apsw' as a require (mga#11368)

* Fri Sep 27 2013 dams <dams> 1.5.0-1.mga4
+ Revision: 487600
- new version 1.5.0

* Thu Sep 26 2013 tv <tv> 1.4.0-2.mga4
+ Revision: 486938
- rebuild for new icu

* Fri Sep 20 2013 dams <dams> 1.4.0-1.mga4
+ Revision: 481740
- new version 1.4.0

* Fri Sep 13 2013 dams <dams> 1.3.0-1.mga4
+ Revision: 478440
- new version 1.3.0

* Fri Sep 06 2013 dams <dams> 1.2.0-1.mga4
+ Revision: 475400
- new version 1.2.0

* Fri Aug 30 2013 dams <dams> 1.1.0-1.mga4
+ Revision: 473503
- It's friday! New version 1.1.0

* Sun Aug 25 2013 tv <tv> 1.0.0-1.mga4
+ Revision: 471543
- BR python-apsw
- new release

* Thu Aug 15 2013 dams <dams> 0.9.43-1.mga4
+ Revision: 466722
- new version 0.9.43

* Fri Aug 02 2013 dams <dams> 0.9.42-1.mga4
+ Revision: 462727
- new version 0.9.42

* Sat Jul 27 2013 dams <dams> 0.9.41-1.mga4
+ Revision: 459122
- new version 0.9.41

* Sat Jul 20 2013 dams <dams> 0.9.40-1.mga4
+ Revision: 456457
- new version 0.9.40

* Fri Jul 12 2013 dams <dams> 0.9.39-1.mga4
+ Revision: 453339
- new version 0.9.39

* Fri Jul 05 2013 dams <dams> 0.9.38-1.mga4
+ Revision: 450279
- new version 0.9.38

* Fri Jun 28 2013 dams <dams> 0.9.37-1.mga4
+ Revision: 447870
- new version 0.9.37

* Sun Jun 23 2013 dams <dams> 0.9.36-2.mga4
+ Revision: 445800
- add 'python-qt4-help' as a require (mga#10180)

* Fri Jun 21 2013 dams <dams> 0.9.36-1.mga4
+ Revision: 445442
- new version 0.9.36

* Fri Jun 14 2013 dams <dams> 0.9.35-1.mga4
+ Revision: 442993
- new version 0.9.35

* Sat Jun 08 2013 dams <dams> 0.9.34-1.mga4
+ Revision: 440741
- fix BR
- new version 0.9.34

* Tue May 28 2013 fwang <fwang> 0.9.32-2.mga4
+ Revision: 429136
- rebuild for new imagemagick

* Tue May 28 2013 dams <dams> 0.9.32-1.mga4
+ Revision: 429013
- new version 0.9.32

* Sun May 26 2013 fwang <fwang> 0.9.31-2.mga4
+ Revision: 427977
- rebuild for new icu

* Thu May 23 2013 dams <dams> 0.9.31-1.mga4
+ Revision: 424957
- new version 0.9.31
- add 'python-cssselect' as a require (mga#10180)

* Fri Apr 05 2013 dams <dams> 0.9.26-1.mga3
+ Revision: 408324
- new version 0.9.26

* Tue Mar 26 2013 dams <dams> 0.9.24-1.mga3
+ Revision: 405291
- new version 0.9.24

* Fri Mar 08 2013 dams <dams> 0.9.22-1.mga3
+ Revision: 401768
- new version 0.9.22
- new version 0.9.21
- new version 0.9.20
- new version 0.9.19

* Fri Feb 01 2013 dams <dams> 0.9.17-1.mga3
+ Revision: 393892
- new version 0.9.17

* Mon Jan 14 2013 dams <dams> 0.9.14-1.mga3
+ Revision: 387888
- new version 0.9.14

* Fri Jan 11 2013 umeabot <umeabot> 0.9.13-2.mga3
+ Revision: 347333
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Office/Other -> Office/Utilities

* Mon Jan 07 2013 dams <dams> 0.9.13-1.mga3
+ Revision: 341054
- new version 0.9.13

* Thu Jan 03 2013 dams <dams> 0.9.12-1.mga3
+ Revision: 337887
- new version 0.9.12
- add 'qt4-devel-private' as buildrequires

* Wed Dec 26 2012 dams <dams> 0.9.11-1.mga3
+ Revision: 335226
- new version 0.9.11

* Fri Dec 14 2012 dams <dams> 0.9.10-1.mga3
+ Revision: 330879
- new version 0.9.10

* Fri Dec 14 2012 fwang <fwang> 0.9.9-2.mga3
+ Revision: 330750
- rebuild for new imagemagick

* Fri Dec 07 2012 dams <dams> 0.9.9-1.mga3
+ Revision: 327822
- new version 0.9.9

* Fri Nov 30 2012 dams <dams> 0.9.8-1.mga3
+ Revision: 323395
- new version 0.9.8

* Fri Nov 23 2012 dams <dams> 0.9.7-1.mga3
+ Revision: 321241
- new version 0.9.7

* Sun Nov 11 2012 dams <dams> 0.9.6-1.mga3
+ Revision: 316968
- new version 0.9.6

* Fri Nov 09 2012 fwang <fwang> 0.9.5-4.mga3
+ Revision: 316611
- rebuild for update icu

* Tue Nov 06 2012 tv <tv> 0.9.5-3.mga3
+ Revision: 315328
- keep calibreSymbols.otf (like FC) so that calibre does start up

* Tue Nov 06 2012 fwang <fwang> 0.9.5-2.mga3
+ Revision: 314760
- rebuild for new icu

* Fri Nov 02 2012 dams <dams> 0.9.5-1.mga3
+ Revision: 312563
- new version 0.9.5

* Mon Oct 29 2012 dams <dams> 0.9.4-1.mga3
+ Revision: 311316
- new version 0.9.4

* Fri Oct 19 2012 dams <dams> 0.9.3-1.mga3
+ Revision: 308303
- It's friday! New version 0.9.3

* Fri Oct 12 2012 fwang <fwang> 0.9.2-2.mga3
+ Revision: 305092
- rebuild for new imagemagick

* Fri Oct 12 2012 dams <dams> 0.9.2-1.mga3
+ Revision: 305046
- It's friday! New version 0.9.2

* Tue Oct 09 2012 dams <dams> 0.9.1-2.mga3
+ Revision: 303954
- rebuild for new python-sip

* Fri Oct 05 2012 dams <dams> 0.9.1-1.mga3
+ Revision: 302854
- It's friday! New version 0.9.1

* Fri Sep 28 2012 dams <dams> 0.9.0-1.mga3
+ Revision: 298983
- update %%Group for new policy
- new version 0.9.0

* Sun Sep 23 2012 dams <dams> 0.8.70-1.mga3
+ Revision: 296834
- new version 0.8.70

* Fri Sep 14 2012 dams <dams> 0.8.69-1.mga3
+ Revision: 293843
- It's friday. So... new version: 0.8.69

* Fri Sep 07 2012 dams <dams> 0.8.68-1.mga3
+ Revision: 289319
- add python-netifaces as require (mga#7368)
- It's friday. So... new version: 0.8.68

* Fri Aug 31 2012 dams <dams> 0.8.67-1.mga3
+ Revision: 286700
- update %%files
- It's friday. So... new version: 0.8.67

* Fri Aug 24 2012 dams <dams> 0.8.66-1.mga3
+ Revision: 283770
- It's friday. So... new version: 0.8.66

* Fri Aug 17 2012 dams <dams> 0.8.65-1.mga3
+ Revision: 281844
- new version 0.8.65
- change Grou

* Sat Aug 11 2012 dams <dams> 0.8.64-1.mga3
+ Revision: 280747
- add libmtp-devel as BuildRequires
- new version 0.8.64

* Fri Aug 03 2012 dams <dams> 0.8.63-1.mga3
+ Revision: 278292
- new version 0.8.63

* Fri Jul 27 2012 dams <dams> 0.8.62-1.mga3
+ Revision: 274973
- new version 0.8.62

* Fri Jul 20 2012 dams <dams> 0.8.61-1.mga3
+ Revision: 272835
- new version 0.8.61

* Sat Jul 14 2012 dams <dams> 0.8.60-1.mga3
+ Revision: 270726
- new version 0.8.60

* Fri Jul 06 2012 dams <dams> 0.8.59-1.mga3
+ Revision: 268488
- update specfile
- new version 0.8.59

* Sat Jun 30 2012 dams <dams> 0.8.58-1.mga3
+ Revision: 265657
- new version 0.8.58

* Fri Jun 22 2012 dams <dams> 0.8.57-1.mga3
+ Revision: 262572
- new version 0.8.57

* Fri Jun 15 2012 dams <dams> 0.8.56-1.mga3
+ Revision: 260845
- new version 0.8.56

* Fri Jun 08 2012 dams <dams> 0.8.55-1.mga3
+ Revision: 257993
- new version

* Fri Jun 01 2012 dams <dams> 0.8.54-1.mga3
+ Revision: 252611
- remove patch6
- new version 0.8.54

* Wed May 30 2012 fwang <fwang> 0.8.53-2.mga3
+ Revision: 249612
- rebuild for new icu

* Mon May 28 2012 dams <dams> 0.8.53-1.mga3
+ Revision: 248366
- Drop man pages patch, as upstream no longer ships man pages
- new version 0.8.53

* Mon May 14 2012 dams <dams> 0.8.51-1.mga2
+ Revision: 235676
- update version on 'python-cssutils' require
- new version 0.8.51

* Mon Apr 23 2012 dams <dams> 0.8.48-1.mga2
+ Revision: 232940
- new version 0.8.48

* Fri Feb 24 2012 dams <dams> 0.8.41-1.mga2
+ Revision: 214114
- new version 0.8.41

* Fri Feb 17 2012 dams <dams> 0.8.40-1.mga2
+ Revision: 210035
- new version 0.8.40

* Fri Feb 17 2012 dams <dams> 0.8.39-1.mga2
+ Revision: 209872
- new version 0.8.39

* Tue Feb 07 2012 dams <dams> 0.8.38-1.mga2
+ Revision: 205679
- new version 0.8.38

* Tue Jan 24 2012 dams <dams> 0.8.36-1.mga2
+ Revision: 200476
- new version 0.8.36

* Fri Jan 13 2012 dams <dams> 0.8.34-1.mga2
+ Revision: 195474
- new version 0.8.34

* Thu Dec 29 2011 dams <dams> 0.8.32-1.mga2
+ Revision: 188703
- BR: change 'sqlite-devel' for 'libsqlite3-devel'
- new version 0.8.32
- rediff patches
- remove patch2
- clean specfile
- source now .tar.xz

* Mon Nov 07 2011 shadow95 <shadow95> 0.8.20-4.mga2
+ Revision: 165128
- add missing Requires poppler (bug #2379)

* Fri Oct 28 2011 fwang <fwang> 0.8.20-3.mga2
+ Revision: 158956
- rebuild for new poppler

* Thu Sep 29 2011 fwang <fwang> 0.8.20-2.mga2
+ Revision: 150125
- rebuild for new podofo

* Tue Sep 27 2011 ovitters <ovitters> 0.8.20-1.mga2
+ Revision: 149629
- fix buildrequires
- fix poppler patch
- rebuild for new poppler
+ fwang <fwang>
- fix build with latest poppler
- new version 0.8.20

* Tue Sep 13 2011 fwang <fwang> 0.8.17-3.mga2
+ Revision: 142952
- rebuild for new libpng

* Tue Sep 13 2011 fwang <fwang> 0.8.17-2.mga2
+ Revision: 142818
- rebuild for new imagemagick

* Tue Sep 06 2011 tv <tv> 0.8.17-1.mga2
+ Revision: 139267
- new release
+ ahmad <ahmad>
- Change libpoppler-*-devel BR to pkgconfig style

* Mon Jul 11 2011 dams <dams> 0.8.9-1.mga2
+ Revision: 122365
- Update to 0.8.9

* Wed Jun 22 2011 dmorgan <dmorgan> 0.8.6-2.mga2
+ Revision: 112024
- Fix file list
- Add Radu Cristian Fotescu changes that fix calibre to start
  Remove macros handled by filetriggers

* Wed Jun 22 2011 dams <dams> 0.8.6-1.mga2
+ Revision: 111827
- Update to 0.8.6
- Rediff patch
- Update spec file for locales deployment
- Update BR

* Sun Mar 27 2011 blino <blino> 0.7.32-3.mga1
+ Revision: 78038
- imported package calibre


* Fri Mar 11 2011 Funda Wang <fwang@mandriva.org> 0.7.32-3mdv2011.0
+ Revision: 643736
- rebuild for new poppler

* Thu Dec 30 2010 Funda Wang <fwang@mandriva.org> 0.7.32-2mdv2011.0
+ Revision: 626152
- rebuild for new poppler

* Sat Dec 04 2010 Tomas Kindl <supp@mandriva.org> 0.7.32-1mdv2011.0
+ Revision: 609311
- update to 0.7.32

* Sun Nov 28 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.31-1mdv2011.0
+ Revision: 602480
- update to 0.7.31
- Make python-fix patch detect the version of python used in the chroot; this way
  one patch can be used for cooker and backports

* Sun Nov 14 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.27-1mdv2011.0
+ Revision: 597480
- Update to 0.7.27

* Mon Nov 01 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.26-1mdv2011.0
+ Revision: 591686
- update to 0.7.26
- rediff python-fix patch. Now there're two patches, one for python-2.7 for distro
  >= 2011.0 and another for python-2.6 for older stable distros (so that it can
  be backported).

* Tue Oct 26 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.24-1mdv2011.0
+ Revision: 589452
- update to 0.7.24

* Tue Oct 12 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.23-1mdv2011.0
+ Revision: 585054
- update to 0.7.23

* Thu Oct 07 2010 Matthew Dawkins <mattydaw@mandriva.org> 0.7.22-1mdv2011.0
+ Revision: 583906
- new version 0.7.22

* Sat Oct 02 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.21-1mdv2011.0
+ Revision: 582432
- update to 0.7.21

* Tue Sep 28 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.20-1mdv2011.0
+ Revision: 581851
- update to 0.7.20

* Sat Sep 18 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.19-1mdv2011.0
+ Revision: 579439
- update to 0.7.19

* Sun Sep 12 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.18-1mdv2011.0
+ Revision: 577831
- update to 0.7.18
- icons are now .png

* Mon Sep 06 2010 Buchan Milne <bgmilne@mandriva.org> 0.7.17-1mdv2011.0
+ Revision: 576247
- update to new version 0.7.17

* Wed Aug 25 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.15-1mdv2011.0
+ Revision: 573287
- update to 0.7.15 (and in the way rebuild for new podofo)

* Sun Aug 22 2010 Funda Wang <fwang@mandriva.org> 0.7.14-2mdv2011.0
+ Revision: 571800
- rebuild for new poppler

  + Tomas Kindl <supp@mandriva.org>
    - bump to 0.7.14

* Sun Aug 08 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.13-1mdv2011.0
+ Revision: 567781
- update to 0.7.13

* Fri Aug 06 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.12-1mdv2011.0
+ Revision: 567146
- update to 0.7.12

* Thu Aug 05 2010 Funda Wang <fwang@mandriva.org> 0.7.10-3mdv2011.0
+ Revision: 566253
- rebuild for new poppler

* Fri Jul 30 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7.10-2mdv2011.0
+ Revision: 563265
- update manpage and no-update patches (from Fedora)
- drop SOURCE1 and python-cssutils hack, it's not needed anymore as
  python-cssutils has been updated to 0.9.7b3
- build with optflags
- delete mimeinfo.cache too

  + Juan Luis Baptiste <juancho@mandriva.org>
    - Updated to 0.7.10, redo diff calibre-no-update.patch.

* Sat Jul 10 2010 Funda Wang <fwang@mandriva.org> 0.6.54-2mdv2011.0
+ Revision: 549995
- rebuild for new imagemagick

  + Tomas Kindl <supp@mandriva.org>
    - various minor SPEC fixes and clean-ups

  + Juan Luis Baptiste <juancho@mandriva.org>
    - Updated to 0.6.54.

* Tue Apr 20 2010 Tomas Kindl <supp@mandriva.org> 0.6.48-1mdv2010.1
+ Revision: 537127
- update to 0.6.48
- fix python-odf and python-django-tagging dependency'

* Tue Apr 20 2010 Tomas Kindl <supp@mandriva.org> 0.6.47-3mdv2010.1
+ Revision: 536983
- fix incorrect odf-py require & bump release
- fix incorrect odf-py require

* Mon Apr 19 2010 Tomas Kindl <supp@mandriva.org> 0.6.47-2mdv2010.1
+ Revision: 536555
- enable PoDoFo dependency as we have PoDoFo in MDV now

* Sun Apr 18 2010 Tomas Kindl <supp@mandriva.org> 0.6.47-1mdv2010.1
+ Revision: 536529
- initial import containing all pertinent fixes to ensure it will build on Mandriva...
- create calibre

